function [output] = autopilotmodel(input)
% -------------------------------------------------------------------------
% > Autopilot model
% -------------------------------------------------------------------------
% > Autopilot model by Andrew Ross (2008)
% > Input vector: [d/dt(r_d),nu,psi_d,r_d]
% > Output vector: [N]
% -------------------------------------------------------------------------

% Rename input vector
dr  = input(1);
u   = input(2);
v   = input(3);
p   = input(5);
r   = input(6);

% Insert identified parameter vector
param = [15.448924
-0.000111
601.738284
-1229.320173
0.203962
38.339076
-12.407592
-0.115149
33.363414
-11.770024
0.126450
-379.979507
-426.124343
-2.953357
-601.738284
601.738284
-0.592199
-0.592181]; %insert parameter vector

% Rename parameter vector
Ndr = param(1);
NuvppL = param(2);
NuvL = param(3);
NuuvL = param(4);
NvvvL = param(5);
NrrvL = param(6);
Nvv = param(7);
Nrv = param(8);
NurL = param(9);
NuurL = param(10);
NrrrL = param(11);
NvvrL = param(12);
Nvr = param(13);
Nrr = param(14);
Xdu0 = param(15);
Ydv0 = param(16);
Ndv0 = param(17);
Ydr0 = param(18);

% Calculate new states
N = (Ndr*dr-NuvppL*u*v*p^2-NuvL*u*v-NuuvL*u^2*v-NvvvL*u^3 ...
     -NrrvL*r^2*v-Nvv*abs(v)*v-Nrv*abs(r)*v-NurL*u*r-NuurL*u^2*r ...
     -NrrrL*r^3-NvvrL*v^2*r-Nvr*abs(v)*r-Nrr*abs(r)*r+(Xdu0-Ydv0)*u*v ...
     -(1/2)*(Ndv0+Ydr0));

output=[N];