% -------------------------------------------------------------------------
% > Data Structure
% -------------------------------------------------------------------------
% > Representing Time-Domain Data as IDDATA Objects
% > Constructing IDNLGREY Object of the models
% -------------------------------------------------------------------------

clc
clear all
close all

%load Simulation/circle_40deg_500
%load Simulation/zigzag_40deg_500
load Simulation/suggested_200

id.startsim = 95; %start simdata
id.endsim = length(simout_time); %end simdata
id.minx = 100; %plot minx
id.maxx = 1800; %plot maxx
id.th = 0;

%% Time-Domain Data as IDDATA Objects
id.u = [simout_rudder_c.signals.values(id.startsim:id.endsim) ...
        simout_u.signals.values(id.startsim:id.endsim) ...
        simout_v.signals.values(id.startsim:id.endsim) ...
        simout_r.signals.values(id.startsim:id.endsim) ...
        simout_psi.signals.values(id.startsim:id.endsim)]; %input
id.y = [simout_r.signals.values(id.startsim:id.endsim)]; %output
id.Ts = 0; %nonuniformly sampled data
id.TimeVector = simout_time(id.startsim:id.endsim)+id.th; %time
data2 = iddata(id.y,id.u,id.Ts,'SamplingInstants',id.TimeVector); %iddata

%% IDNLGREY Object | Nomoto autopilot model
nom.FileName = 'model_nomoto'; %file describing the model structure
nom.Order = [1 5 1]; %model orders [ny nu nx]
nom.Parameters = [-0.15; 3]; %initial parameters
nom.InitialStates = [0]; %initial initial states
nom.Ts = 0; %time-continuous system
nom.nlgr = idnlgrey(nom.FileName, nom.Order, nom.Parameters, ...
                    nom.InitialStates, nom.Ts, 'Name', 'Nomoto Model');

%% IDNLGREY Object | Ross autopilot model
ros.FileName = 'model_ross'; %file describing the model structure
ros.Order = [1 5 1]; %model orders [ny nu nx]
ros.Parameters = [15; 0; 200; -400; 0.01; -2; 70; -8; 11; -2.5; 0.05; ...
                  100; -10; -1; -200; 200; -0.05; -0.05; ]; %init param.
ros.InitialStates = [0]; %initial initial states
ros.Ts = 0; %time-continuous system
ros.nlgr = idnlgrey(ros.FileName, ros.Order, ros.Parameters, ...
                     ros.InitialStates, ros.Ts, 'Name', 'Ross Model');

display Data_Structure_Created