% -------------------------------------------------------------------------
% > Main initialization
% -------------------------------------------------------------------------

clc
clear all

vessel.n0 = 0; %init pos [m]
vessel.e0 = 0; %init pos [m]
vessel.phi0 = 0; %init roll ang [rad]
vessel.psi0 = 0; %init yaw ang [rad]

vessel.u0 = 0;%1.56; %init surge vel [m/s]
vessel.v0 = 0; %init sway vel [m/s]
vessel.p0 = 0; %init roll rate [rad/s]
vessel.r0 = 0; %init yaw rate [rad/s]

vessel.eta0 = [vessel.n0 vessel.e0 vessel.psi0]';
vessel.nu0 = [vessel.u0 vessel.v0 vessel.r0]';
vessel.init = [vessel.eta0; vessel.nu0];


%% Rudder
rudder.max = 45; %60; %max rudder [deg]
rudder.rate = 15.0; %max rudder rate [deg/s]
rudder.ts = 1; %time constant [s]
rudder.surge = 0.7; %0.3; %rudder effect on surge
rudder.sway = 4.0;%1.5%2.5; %rudder effect on sway
rudder.roll = 0.6; %rudder effect on roll
rudder.yaw = -2.3; %6.3 %-3.3%-5.3; %rudder effect on yaw

%% Thrust
thrust.max = 500; %max RPM
thrust.rate = 100; %max RPM Rate
thrust.ts = 1; %time constant [s]
thrust.rudder_fluid_vel = 1/200; %generated fluid velocity
thrust.effect = 0.05; %thrust effect on surge

%% Turning Circle
maneuver.circle = 45; %turning circle rudder deflection [deg]
maneuver.circle_threshold = 100; %threshold time [s]

%% Zig-zag Maneuver
maneuver.zigzag = 20; %zig-zag test [deg]
maneuver.zigzag_threshold = 100; %threshold time [s]

%% The suggested Variable Step Maneuver
maneuver.new_step = [0 5 10 20 30 40 45 0 0]; %rudder steps [deg]
maneuver.new_param = [100 2 0.3]; %threshold,switch,ramp

%% Autopilot
%Controller
autopilot.wb = 0.05; %bandwidh
autopilot.xi = 1.5; %relative damping ratio
autopilot.wn = (1/(sqrt(1-2*autopilot.xi^2+sqrt(4*autopilot.xi^4 ...
                -4*autopilot.xi^2+2))))*autopilot.wb; %natural frequency

%Calculate controller gain
autopilot.Kp = (190*autopilot.wn^2)
autopilot.Kd = (2*autopilot.xi*autopilot.wn*190)
autopilot.Ki = ((autopilot.wn/10)*autopilot.Kp)

%Nomoto model reference forward
autopilot.ffK = 0.107937
autopilot.ffT = 4.467136

%% Reference model
refmod.xi = 1; %relative damping ratio
refmod.wn = 0.2; %natural frequency
refmod.max_velocity = 10; %saturate r_ref [deg/s]

%% Reference step
reference.steptime = 100;
reference.init = 0;
reference.step = 45;

display Initialization_completed


