function [output] = suggested_maneuver(input)
% -------------------------------------------------------------------------
% > Suggested ship maneuver
% -------------------------------------------------------------------------
% > Input vector: [clock,param,step]
% > Output vector: [rudder]
% -------------------------------------------------------------------------

% Rename input vector
clock = input(1);
threshold_start = input(2);
threshold_switch = input(3);
ramp = input(4);
rudder_step = input(5:13);

persistent stepNumber; %define persistent counter
persistent threshold_temp; %define persistent threshold
persistent stepNow; %define persistent psi
persistent stepPhase; %define persistent step phase
persistent out; %define persistent output

if isempty(out)
    out = 0;
end

if isempty(stepPhase)
    stepPhase = 0;
end

if isempty(stepNow)
    stepNow = 0;
end

if isempty(stepNumber)
    stepNumber = 1;
end

if isempty(threshold_temp)
    threshold_temp = 0;
end

if(clock > threshold_start)
    if(stepNumber == 1)
        stepNumber = 2;
        stepPhase = 1;
        threshold_temp = clock;
        out = -rudder_step(stepNumber);
    end
end

threshold_switch = threshold_switch*rudder_step(stepNumber);

if(stepNumber > 1 && stepNumber < 9)
    if(stepPhase == 1 && ((threshold_temp + threshold_switch) < clock))
        out = -rudder_step(stepNumber) +(clock - threshold_temp - ...
              threshold_switch)*ramp;
        if(out > 0)
            stepPhase = 2;
        end
    elseif(stepPhase == 2 && ((threshold_temp + threshold_switch) ...
           < clock))
        stepPhase = 3;
        threshold_temp = clock;
        out = rudder_step(stepNumber);
    elseif(stepPhase == 3 && ((threshold_temp + threshold_switch) < clock))
        out = rudder_step(stepNumber) -(clock - threshold_temp - ...
              threshold_switch)*ramp;
        if(out < 0)
            stepPhase = 4;
        end
    elseif(stepPhase == 4 && ((threshold_temp + threshold_switch) ...
           < clock))
        stepNumber = stepNumber + 1;
        stepPhase = 1;
        threshold_temp = clock;
        out = -rudder_step(stepNumber);
    end
end

if(stepNumber > 8)
    out = 0;
end

output=[out];
